@@ -21,7 +21,7 @@ class GnomeTweaks(Gtk.Application):
 
     def __init__(self):
         GLib.set_application_name(_("GNOME Tweaks"))
-        Gtk.Application.__init__(self, application_id="org.gnome.Tweaks")
+        Gtk.Application.__init__(self, application_id="org.gnome.tweaks")
         self.win = None
 
     def do_activate(self):
@@ -29,19 +29,12 @@ class GnomeTweaks(Gtk.Application):
             model = TweakModel()
             self.win = Window(self, model)
             self.win.show_all()
+            self.win.back_button.props.visible = False
         self.win.present()
 
     def do_startup(self):
         Gtk.Application.do_startup(self)
 
-        self.builder = Gtk.Builder()
-        assert(os.path.exists(gtweak.PKG_DATA_DIR))
-        filename = os.path.join(gtweak.PKG_DATA_DIR, 'shell.ui')
-        self.builder.add_from_file(filename)
-
-        appmenu = self.builder.get_object('appmenu')
-        self.set_app_menu(appmenu)
-
         reset_action = Gio.SimpleAction.new("reset", None)
         reset_action.connect("activate", self.reset_cb)
         self.add_action(reset_action)
@@ -58,10 +51,6 @@ class GnomeTweaks(Gtk.Application):
         about_action.connect("activate", self.about_cb)
         self.add_action(about_action)
 
-        quit_action = Gio.SimpleAction.new("quit", None)
-        quit_action.connect("activate", self.quit_cb)
-        self.add_action(quit_action)
-
     def reset_cb(self, action, parameter):
         dialog = Gtk.MessageDialog(self.win, 0, Gtk.MessageType.QUESTION,
                                    Gtk.ButtonsType.OK_CANCEL, _("Reset to Defaults"))
@@ -93,7 +82,7 @@ class GnomeTweaks(Gtk.Application):
         else:
             about_comment = _("GNOME Shell is not running")
 
-        about_comment += "\n" + _("GTK+") + " %d.%d.%d" % \
+        about_comment += "\n" + _("GTK") + " %d.%d.%d" % \
             (Gtk.get_major_version(), Gtk.get_minor_version(), Gtk.get_micro_version())
         aboutdialog.set_comments(about_comment)
 
